![PyPI](https://img.shields.io/pypi/v/tree-sitter-talon)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/py-tree-sitter-talon)
[![GitHub Workflow Status](https://github.com/wenkokke/py-tree-sitter-talon/actions/workflows/ci.yml/badge.svg)](https://github.com/wenkokke/py-tree-sitter-talon/actions/workflows/ci.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/wenkokke/py-tree-sitter-talon/dev.svg)](https://results.pre-commit.ci/latest/github/wenkokke/py-tree-sitter-talon/dev)

# Parser for Talon files in Python

See [the documentation](https://wen.works/py-tree-sitter-talon).
